apc.indiv.LRtable.TS <- function(data,  dep.var, covariates=NULL, unit=1, 
                                 n.coh.excl.start=0, n.coh.excl.end=0, 
                                 n.age.excl.start=0, n.age.excl.end=0,
                                 n.per.excl.start=0, n.per.excl.end=0,
                                 maxit.loop.TS=10,
                                 maxit.linesearch.TS=30, init.TS="ols"){
  # Step 1: function to write table lines
  get.table.line <- function(LRtest.TS, LRtest.APC, first=FALSE, second=FALSE){
    if(isTRUE(first)) # first line is TS model so not compared to itself/APC submodel
      line <- c(NA, NA, NA, NA, NA, NA, round(LRtest.TS$aic.big, 3), round(LRtest.TS$lik.big, 3))
    else if(isTRUE(second)) # second line is full APC model so not compared to itself
      line <- c(round(LRtest.TS$LR, 3), LRtest.TS$df, round(LRtest.TS$p.value, 3), NA,
                NA, NA, round(LRtest.TS$aic.small, 3), round(LRtest.TS$lik.small, 3))
    else
      line <- c(round(LRtest.TS$LR, 3), LRtest.TS$df, round(LRtest.TS$p.value, 3), 
                round(LRtest.APC$LR, 3),
                LRtest.APC$df, round(LRtest.APC$p.value, 3), round(LRtest.APC$aic.small, 3),
                round(LRtest.APC$lik.small, 3))
    return(line)
  }
  ######################	
  # Step 2: other setup
  
  # Submodel list
  model.design.list <- c("TS", "APC", "AP", "AC", "PC", "Ad", "Pd", "Cd", 
                         "A", "P", "C", "t", "tA", "tP", "tC", "1")
  # Empty table
  fit.tab <- matrix(nrow=length(model.design.list), ncol=8, data=NA)
  # Full APC model for comparison
  fullAPCcollinear <- apc.indiv.design.collinear(data,  unit=unit, 
                                                 n.coh.excl.start = n.coh.excl.start, 
                                                 n.coh.excl.end = n.coh.excl.end,
                                                 n.age.excl.start = n.age.excl.start,
                                                 n.age.excl.end = n.age.excl.end,
                                                 n.per.excl.start = n.per.excl.start,
                                                 n.per.excl.end = n.per.excl.end)
  fullAPCdesign <- apc.indiv.design.model(fullAPCcollinear, dep.var = dep.var, 
                                          covariates = covariates)
  fullAPCfit <- apc.indiv.fit.model(fullAPCdesign, model.family="binomial")
  # TS model for comparison
  TSfit <- apc.indiv.logit.TS(data, dep.var=dep.var, covariates=covariates, 
                              maxit.loop = maxit.loop.TS,
                              maxit.linesearch = maxit.linesearch.TS, init = init.TS)
  ######################	
  # Step 3: Generate table
  
  # first line, TS model and second line, full APC model
  LRtest.full.vs.TS <- apc.indiv.LRtest.TS(existing.small.model.fit = fullAPCfit, 
                                           existing.big.model.fit = TSfit)
  first.line <- get.table.line(LRtest.TS=LRtest.full.vs.TS, first=TRUE)
  second.line <- get.table.line(LRtest.TS=LRtest.full.vs.TS, second=TRUE)
  fit.tab[1, 1:8] <- first.line
  fit.tab[2, 1:8] <- second.line
  # Remaining submodels
  for (i in 3:length(model.design.list)){
    againstTS <- apc.indiv.LRtest.TS(data, small.model=model.design.list[i],
                                     dep.var = dep.var,covariates = covariates, 
                                     unit = unit,
                                     n.coh.excl.start = n.coh.excl.start, 
                                     n.coh.excl.end = n.coh.excl.end,
                                     n.age.excl.start = n.age.excl.start,
                                     n.age.excl.end = n.age.excl.end,
                                     n.per.excl.start = n.per.excl.start,
                                     n.per.excl.end = n.per.excl.end,
                                     existing.big.model.fit = TSfit, 
                                     existing.collinear = fullAPCcollinear)
    againstAPC <- apc.indiv.LRtest.fullapc(data,  small.model = model.design.list[i],
                                           dep.var=dep.var, covariates=covariates, unit = unit, 
                                           n.coh.excl.start = n.coh.excl.start, 
                                           n.coh.excl.end = n.coh.excl.end,
                                           n.age.excl.start = n.age.excl.start,
                                           n.age.excl.end = n.age.excl.end,
                                           n.per.excl.start = n.per.excl.start,
                                           n.per.excl.end = n.per.excl.end,
                                           existing.big.model.fit = fullAPCfit, 
                                           existing.collinear = fullAPCcollinear)
    fit.tab[i, 1:8] <- get.table.line(againstTS, againstAPC)
  }
  # Change table column and row names
  
  table.colnames <- c("LR-test vs TS", "df", "p-value", "LR-test vs APC", 
                      "df", "p-value", "AIC", "Loglihood")
  colnames(fit.tab) <- table.colnames
  rownames(fit.tab) <- model.design.list
  ####################
  valuables <- list(table = fit.tab,
                    NR.report = againstTS$NR.report)
  return(valuables)
}