apc.indiv.LRtest.TS <- function(data, small.model="APC", dep.var, covariates=NULL,
                                model.family="binomial", unit=1, 
                                n.coh.excl.start=0, n.coh.excl.end=0,
                                n.age.excl.start=0, n.age.excl.end=0,
                                n.per.excl.start=0, n.per.excl.end=0,
                                existing.small.model.fit=NULL, existing.big.model.fit=NULL, 
                                existing.collinear=NULL,
                                maxit.loop.TS=10, maxit.linesearch.TS=30, 
                                init.TS="ols"){
  # step 1: fit APC model
  if(is.null(existing.small.model.fit)){
    if(is.null(existing.collinear)){
      collinear <- apc.indiv.design.collinear(data,  unit = unit,
                                              n.coh.excl.start = n.coh.excl.start,
                                              n.coh.excl.end = n.coh.excl.end,
                                              n.age.excl.start = n.age.excl.start,
                                              n.age.excl.end = n.age.excl.end,
                                              n.per.excl.start = n.per.excl.start,
                                              n.per.excl.end = n.per.excl.end)
    } else collinear <- existing.collinear
    design <- apc.indiv.design.model(collinear, model.design = small.model,
                                     dep.var=dep.var, covariates=covariates)
    APC.model <- apc.indiv.fit.model(design, model.family=model.family)
  } else 
    APC.model <- existing.small.model.fit
  lik.APC <- -0.5*APC.model$deviance
  
  # step 2: fit TS model
  if(is.null(existing.big.model.fit)){
    TS.model <- apc.indiv.logit.TS(data, dep.var=dep.var, covariates=covariates,
                                   maxit.loop = maxit.loop.TS,
                                   maxit.linesearch = maxit.linesearch.TS, 
                                   init = init.TS)
  } else
    TS.model <- existing.big.model.fit
  
  # step 3: run LR test
  diff.df <- TS.model$param.dimension - length(APC.model$coefficients)
  diff.lik <- lik.APC - TS.model$likelihood
  p.value <- pchisq(-2*diff.lik, df = diff.df, lower.tail = FALSE)
  
  aic.apc <- APC.model$aic
  aic.TS <- TS.model$aic
  
  NR.report <- list(result = TS.model$result, 
                    n.loop.iterations = TS.model$n.loop.iterations, 
                    n.linesearch.iterations = TS.model$n.linesearch.iterations, 
                    d1_new = TS.model$d1_new, 
                    norm.d1 = TS.model$norm.d1)
  
  # step 4: extract valuables
  valuables <- list(LR = -2*diff.lik,
                    df = diff.df,
                    p.value = p.value,
                    aic.small = aic.apc,
                    aic.big = aic.TS,
                    lik.small = lik.APC,
                    lik.big = TS.model$likelihood,
                    NR.report = NR.report)
  return(valuables)
}