apc.indiv.LRtest.fullapc <- function(data,  big.model="APC", 
                                     small.model,
                                     dep.var, covariates=NULL, 
                                     model.family="binomial", unit=1,
                                     n.coh.excl.start=0, n.coh.excl.end=0,
                                     n.age.excl.start=0, n.age.excl.end=0,
                                     n.per.excl.start=0, n.per.excl.end=0,
                                     existing.big.model.fit=NULL,
                                     existing.small.model.fit=NULL,
                                     existing.collinear=NULL){
  # step 1: fit reduced model
  
  if(is.null(existing.small.model.fit)){
    if(is.null(existing.collinear)){
      collinear.R <- apc.indiv.design.collinear(data,  unit = unit,
                                                n.coh.excl.start = n.coh.excl.start, 
                                                n.coh.excl.end = n.coh.excl.end,
                                                n.age.excl.start = n.age.excl.start,
                                                n.age.excl.end = n.age.excl.end,
                                                n.per.excl.start = n.per.excl.start,
                                                n.per.excl.end = n.per.excl.end)
    } else
      collinear.R <- existing.collinear
    design.R <- apc.indiv.design.model(apc.indiv.design.collinear = collinear.R, 
                                       model.design = small.model, dep.var=dep.var,
                                       covariates=covariates)
    reduced.model <- apc.indiv.fit.model(design.R, model.family=model.family)
  } else 
    reduced.model <- existing.small.model.fit
  
  # step 2: fit APC model
  if(is.null(existing.big.model.fit)){
    # note: can use same collinear design matrix for full model as for submodel
    design.U <- apc.indiv.design.model(apc.indiv.design.collinear = collinear.R, 
                                       model.design = big.model, dep.var=dep.var,
                                       covariates=covariates)
    APC.model <- apc.indiv.fit.model(design.U, model.family=model.family)
  } else 
    APC.model <- existing.big.model.fit  
  
  
  # step 3: run LR test
  lik.reduced <- -0.5*reduced.model$deviance
  lik.APC <- -0.5*APC.model$deviance
  
  diff.df <- length(APC.model$coefficients) - length(reduced.model$coefficients)
  diff.lik <- lik.reduced - lik.APC
  p.value <- pchisq(-2*diff.lik, df=diff.df, lower.tail=FALSE)
  
  aic.reduced <- reduced.model$aic
  aic.big <- APC.model$aic
  
  # step 4: extract valuables
  valuables <- list(LR = -2*diff.lik,
                    df = diff.df,
                    p.value = p.value,
                    aic.big = aic.big,
                    aic.small = aic.reduced,
                    lik.big = lik.APC,
                    lik.small = lik.reduced)
  
  return(valuables)
}