apc.indiv.ftest.TS <- function(data,  small.model="APC",
                               dep.var, covariates=NULL,
                               model.family="gaussian", unit=1, 
                               n.coh.excl.start=0, n.coh.excl.end = 0,
                               n.age.excl.start=0, n.age.excl.end = 0,
                               n.per.excl.start=0, n.per.excl.end = 0,
                               existing.small.model.fit=NULL, 
                               existing.big.model.fit=NULL, existing.collinear=NULL){
  ######################	
  # This function runs an F-test comparing the fit of a single 
  # APC model or submodel to the temporally-saturated model.
  ######################	
  # Step 1: Fit APC model
  
  if(is.null(existing.small.model.fit)){
    if(is.null(existing.collinear)){
      collinear <- apc.indiv.design.collinear(data, 
                                              unit = unit,
                                              n.coh.excl.start = n.coh.excl.start,
                                              n.coh.excl.end = n.coh.excl.end,
                                              n.age.excl.start = n.age.excl.start,
                                              n.age.excl.end = n.age.excl.end,
                                              n.per.excl.start = n.per.excl.start,
                                              n.per.excl.end = n.per.excl.end)
    } else collinear <- existing.collinear
    design <- apc.indiv.design.model(collinear, model.design = small.model, 
                                     dep.var=dep.var, covariates=covariates)
    fitted <- apc.indiv.fit.model(design, model.family=model.family)
  } else 
    fitted <- existing.small.model.fit
  
  # get RSS, number of parameters, number of observations for APC model.
  RSS.APC <- sum(fitted$residuals^2)
  
  nparam.APC <- length(fitted$coefficients)
  sample.N.APC <- length(fitted$y)
  ######################	
  # Step 2: Fit TS model
  
  if(is.null(existing.big.model.fit)){
    dummymodel <- apc.indiv.estimate.TS(data, dep.var = dep.var, 
                                        covariates = covariates)
  } else
    dummymodel <- existing.big.model.fit
  
  # get RSS, number of parameters from TS model.
  RSS.dummy <- dummymodel$RSS
  if (!is.na(dummymodel$zetahat[1])){
    nparam.dummy <- dummymodel$n.cells+length(dummymodel$zetahat)
  } else{
    nparam.dummy <- dummymodel$n.cells
  }
  ######################	
  # step 3: Run F-test
  
  # Elements of F-test
  big.model.RSS <- RSS.dummy
  small.model.RSS <- RSS.APC
  big.model.nparams <- nparam.dummy
  small.model.nparams <- nparam.APC
  sample.N <- sample.N.APC
  
  df.num <- big.model.nparams - small.model.nparams
  df.denom <- sample.N - big.model.nparams
  df <- paste("(", paste(as.character(df.num), as.character(df.denom), 
                         sep=", "), ")", sep="")
  
  # Combine elements in F-statistic
  fstat.num <- (small.model.RSS - big.model.RSS)/df.num
  fstat.denom <- (big.model.RSS - 0)/df.denom
  fstat <- fstat.num/fstat.denom
  
  # Get p-value by comparing F-statistic to F-distribution
  p.value <- pf(fstat, df1 = df.num, df2 = df.denom, lower.tail = FALSE)
  ######################	
  # valuables
  valuables <- list(fstat = fstat,
                    df = df,
                    df.num = df.num,
                    df.denom = df.denom,
                    p.value = p.value,
                    aic.small = fitted$aic,
                    aic.big = dummymodel$aic,
                    lik.small = fitted$likelihood,
                    lik.big = dummymodel$likelihood)
  return(valuables)
}